--
--	Code commands
--
--	&1	--	opcode number
--	&2	--	operand count
--
--	Each model state codes 3 parameters starting with &3.
--	So,	operand 0 spans &3, &4 &5
--		operand 1 spans &6, &7, &8
--		operand 2 spans &9, &10, &11
--		operand 3 spans &12, &13, &14
--		operand 4 spans &15, &16, &17
--		msgId is &18
--
--	For each operand triple:
--		+0	--	= 1 to invert the logical sense of the operand state.  0 otherwise.
--		+1	--	indicates a Qbn section-record number pair or literal value
--				(if = 0x12345678)
--		+2	--	= record number of a section or a literal value (according to
--				how +1 was set)
--
--	Generally, use the +1 index for symbolic variables, like item names or
--	clock names, and the +2 form for numeric values (e.g. Qrc message numbers)
--
--	That is, &4, &7, &10, &13, &16 will construct the section-record number
--	pair automatically any time they do not have numerical values assigned
--	to them by the template.  That constructed record number will be propagated
--	to the +2 field as expected by the X-engine.
--
--	Likewise, &5, &8, &11, &14, &17 will construct a numerical value, or
--	attempt to reduce a symbolic value (like a name of a Qrc stock message
--	block) to a pure number.
--
--	Since operand 0 is universally the task state bound to the operation code,
--	it is rarely mentioned in the subsequent command templates.  Ordinarily
--	the cataloguer handles the mechanics of binding the right task state
--	to the operation code.  Some operation codes create new task states
--	and some templates bring the task creation step and operation step
--	together into a single template.
--
--	There are several sorts of opcode formats.
--
--		6	--	Ordinary opcode (inherits current condition-response context)
--		7	--	Start a new condition-response context
--		8	--	Variable opcode (within current c-r)
--		9	--	Start a new condition-response context with a variable opcode
--
--	Variable opcodes are described by a 'stack' of potential opcodes bytes in &1.
--		0x000000ff	--	selects the opcode when the key parameter (often &7)
--						resolves to an item-type
--		0x0000ff00	--	selects the opcode when the key parameter resolves to
--						a faction-type
--		0x00ff0000	--	selects the opcode when the key parameter resolves to
--						a location-type
--		0xff000000	--	selects the opcode when the key parameter resolves to
--						a foe-type
--
--	When a new condition-response context is started (formats 7 or 9), the
--	opcode (or stack) may be negated to indicate the inverse state of the
--	the defining condition-response.  (Eg 'when not foo' as against 'when foo')
--
--	The template processor will object if we assign a default value (#n) after
--	its symbolic mention (&n), but we use the alternate order to assign a section
--	limit to the symbol.  So the construct
--
--		#10=4 foo &10
--
--	informs the resolver apparatus to forbid any symbolic replacement for &10
--	which does not resolve to section 4 (places) of the Qbn file.  This lets
--	us fabricate command patterns that create sane instructions without the
--	formalities of fully typed language, since mostly we don't care about type.
--	Use section 10 for Qrc message block numbers.
--
--	X-engine has several ways of bestowing a new item on the player, depending
--	on the sort of side-effects the quest author desires.  This is not always
--	obvious from the command patterns so some commentary is in order here.
--
--	'get item' bestows a quest related item directly into the pc's inventory
--	without notice to the player.  It usually refers to an amount of gold
--	donated by the questor to the pc, but there doesn't appear to be a specific
--	requirement that the item be gold.
--
--	'give item' bestows one or more quest items through the inventory picklist
--	(as though the player were buying/selling in a shop.  Presumably the player
--	can elect to ignore the proffered trinket(s) and go on his way.  Items
--	so acquired, even if 'quest marked' with the green background belong to
--	the player even after the quest proper has ended.  Some quests apparently
--	bestow nothing on the pc through this command.  Perhaps it acts as a
--	kind of no-op in that context by creating a do-nothing response.
--
--	'give item notify' bestows a quest related item directly into the player's
--	inventory with a notification message posted from some Qrc text.
--
--	'give item to <foe>' installs a quest item in the foe's inventory, where
--	it can be recovered from its corpse, or presumably through pickpocketing.
--
--	'get item from -foo-' is like 'get item' but specifies a particular npc,
--	apparently under the presumption that the item has been placed in that npc's
--	possession.  (But there does not appear to be any pseudo-code operation to
--	associate an item with an npc, unless the code for give item to foe also
--	works for persons as well)  This operation appears only in S0000008,
--	when you give the totem to Gortwog and he rewards you with money.
--
--	'reveal' has two flavors, local and global.  The simpler form reveals the
--	location of a hidden dungeon on the world map for the current provence.
--	The complex form reveals the location of a hidden dungeon on the world map
--	of a different province (as for example Scourg Burrow or Dirinni Tower)
--	The additional details inform the X-engine how to locate that remote
--	province.  The first of the triple is the place symbol in the current
--	quest.  The next is a province number and the last is a 'magic number'
--	to locate the exterior point of the dungeon.  Since the number of these
--	spots is fixed by the game design, there isn't any real hope of extending
--	them ad hoc.  The separate ATLAS tool will construct a suitable model
--	for a global reveal command of any Daggerfall site.
--
--	'mute npc' makes that npc ignore any approaches by the player for the
--	duration of the quest.  Some main quests for example let the player offer
--	quest items to one of several characters.  But once the offer is made, the
--	other npcs involved must be 'programmed' to ignore the pc if approached.
--	Specifically, it ignores mouse clicks on the npc in question.
--
--	'add questor'/'drop questor'  In guild quests, the questor is normally the
--	person clicked to launch the quest and to whom the pc usually must report
--	to complete a quest successfully.  Main story quests don't have this
--	convention and so a mechanism exists to designate npcs (usually of the
--	'permanent' flavor) as the questor d'jure.  Once that phase of the quest
--	is completed, that npc is dropped as the questor.
--
--	'play sound' is presently used only for the ghost of King Lysandus roving
--	the streets of Daggerfall.  The first number seems to be the index of the
--	sound to play, while the latter two parameters seem to be a time range
--	in game minutes.
--
--	Also note that some op-codes imply the creation of a new task block.  When
--	a task is composed with more than one starting code, the triggers can be
--	implicity linked together as logical 'or' conditions.  The decompiler uses
--	a simple sorting algorithm and will apparently botch very complex cases
--	when the triggering op-codes are sorted within the response codes.  It
--	makes for odd code-reading, but X-engine appears not to care overmuch
--	about the order of the context appearances in the Qbn file--quest
--	initialization being the obvious exception.
--
--	In the command forms, such events tend to report the past tense (clicked,
--	dropped, used, killed, etc)  though progressive appears from time to time
--	(eg. toting, saying)
--
--
--	Opcodes starting a fresh c-r context:
--
7 &3 task                              #1=0 #2=0
7 &3 task:                             #1=0 #2=0
7 &3 timer                             #1=0 #2=0
7 &3 timer:                            #1=0 #2=0 
7 until &3 performed:                  #1=0 #2=0
7 variable &3                          #1=0 #2=0
7 variable &3 global &2                #1=1
9       from &8 to &11 daily           #1=31         #2=3 #6=0 #7=0x12345678 #9=0 #10=0x12345678
7       &4 when &7                     #1=52         #2=5 #6=0 #9=0 #10=0x12345678 #11=-2 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
7 #10=4 when pc at &10                 #1=43         #2=3 #6=0 #9=0
7 #10=4 &7 when pc at &10              #1=43         #2=3 #6=0 #9=0
7 #10=4 when pc not at &10             #1=-43        #2=3 #6=0 #9=0
7 #10=4 &7 when pc not at &10          #1=-43        #2=3 #6=0 #9=0
9       when &7 clicked                #1=0x1c03     #2=2 #6=0
9       &4 when &7 clicked             #1=0x1c03     #2=2 #6=0
7       when &7 dropped at &10         #1=5          #2=3 #6=0 #9=0
6       when toting &10 do &4          #1=70         #2=5 #6=0 #9=0 #12=0 #13=0xff #14=-1 #15=0 #16=0xff #17=-1
7       when toting &7 and &10 clicked #1=1          #2=3 #6=0 #9=0
7       when &7 injured                #1=21         #2=2 #6=0
9       when &7 killed                 #1=0x02000000 #2=3 #6=0 #9=0 #10=0x12345678 #11=1
9       when &11 &7 killed             #1=0x02000000 #2=3 #6=0 #9=0 #10=0x12345678
7 #10=0 when &10 used                  #1=57         #2=3 #6=0 #9=0
7 #10=0 when &10 used saying &18       #1=57         #2=3 #6=0 #9=0
7 #10=0 &7 when &10 used               #1=57         #2=3 #6=0 #9=0
7 #10=0 &7 when &10 used saying &18    #1=57         #2=3 #6=0 #9=0
-7 #11=11 when &11 spell cast do &7    #1=73         #2=3 #6=0 #9=0 #10=0x12345678 #11=51
--
--	Opcodes inheriting the current c-r context:
--
6 add &7 face                             #1=55 #2=2 #6=0
6 add &7 face saying &18                  #1=55 #2=2 #6=0
6 add &7 as questor                       #1=85 #2=2 #6=0
6 add dialog for location &7 person &10 item &13    #1=10 #2=4 #6=0 #9=0 #12=0
6 add dialog for location &7 person &10             #1=10 #2=4 #6=0 #9=0 #12=0 #13=0xff #14=-1
6 add dialog for person &10 item &13                #1=10 #2=4 #6=0 #7=0x04ff #8=-1 #9=0 #12=0
6 add dialog for item &13                 #1=10 #2=4 #6=0 #7=0x04ff #8=-1 #9=0 #10=0x03ff #11=-1 #12=0
6 add dialog for person &10               #1=10 #2=4 #6=0 #7=0x04ff #8=-1 #9=0   #12=0 #13=0xff #14=-1
6 add dialog for location &7              #1=10 #2=4 #6=0 #9=0 #10=0x03ff #11=-1 #12=0 #13=0xff #14=-1
6 dialog link for item &13                #1=11 #2=4 #6=0 #7=0x04ff #8=-1 #9=0   #10=0x03ff #11=-1 #12=0
6 dialog link for person &10              #1=11 #2=4 #6=0 #7=0x04ff #8=-1 #9=0   #12=0 #13=0xff #14=-1
6 dialog link for location &7             #1=11 #2=4 #6=0 #9=0 #10=0x03ff #11=-1 #12=0 #13=0xff #14=-1
6 dialog link for location &7 item &13    #1=11 #2=4 #6=0 #9=0 #10=0x03ff #11=-1 #12=0
6 dialog link for location &7 person &10  #1=11 #2=4 #6=0 #9=0 #12=0 #13=0xff #14=-1
6 dialog link for person &10 item &13     #1=11 #2=4 #6=0 #7=0x04ff #8=-1 #9=0 #12=0
6 dialog link for location &7 person &10 item &13  #1=11 #2=4 #6=0 #9=0 #12=0
6 add foe &7 face              #1=63 #2=2 #6=0
6 #10=11      cast &10 spell do &7  #1=73 #2=3 #6=0 #9=0
6 #7=7 #10=11 cast &10 spell on &7  #1=69 #2=3 #6=0 #9=0
6 remove log step &8           #1=24 #2=2 #6=0 #7=0x12345678
6 change repute with &7 by &11 #1=61 #2=3 #6=0 #9=0 #10=0x12345678
6 change repute with &7 by &11 saying &18 #1=61 #2=3 #6=0 #9=0 #10=0x12345678
6 clear &7 &10 &13 &16         #1=7  #2=5 #6=0 #9=0 #12=0 #15=0
6 clear &7 &10 saying &18      #1=7  #2=5 #6=0 #9=0 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 clear &7 &10 &13             #1=7  #2=5 #6=0 #9=0 #12=0 #15=0 #16=0x09fe #17=-2
6 clear &7 &10                 #1=7  #2=5 #6=0 #9=0 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 clear &7                     #1=7  #2=5 #6=0 #9=0 #10=0x09fe #11=-2 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
8 clicked &7                   #1=0x1c03 #2=2 #6=0
8 clicked &7 say &18           #1=0x1c03 #2=2 #6=0
6 clicked item &7              #1=3  #2=2 #6=0
6 clicked item &7 say &18      #1=3  #2=2 #6=0
6 clicked npc &7               #1=28 #2=2 #6=0
6 clicked npc &7 say &18       #1=28 #2=2 #6=0
6 #13=3 clicked &13 and at least &11 gold otherwise do &7              #1=71 #2=4 #6=0 #9=0 #10=0x12345678 #12=0
6 #7=7 create &7 every &11 minutes &17 times with &14 success          #1=9  #2=5 #6=0 #9=0 #10=0x12345678 #12=0 #13=0x12345678 #15=0 #16=0x12345678
6 #7=7 create &7 once                                                  #1=9  #2=5 #6=0 #9=0 #10=0x12345678 #11=1 #12=0 #13=0x12345678 #14=100 #15=0 #16=0x12345678 #17=1
6 create foe  &7 every &11 minutes &17 times with &14 success          #1=9  #2=5 #6=0 #9=0 #10=0x12345678 #12=0 #13=0x12345678 #15=0 #16=0x12345678
6 create foe  &7 every &11 minutes &17 times with &14 success msg &18  #1=9  #2=5 #6=0 #9=0 #10=0x12345678 #12=0 #13=0x12345678 #15=0 #16=0x12345678
6 create foe  &7 every &11 minutes indefinitely with &14 success       #1=9  #2=5 #6=0 #9=0 #10=0x12345678 #12=0 #13=0x12345678 #15=0 #16=0x12345678 #17=-1
6 create npc at &7             #1=81 #2=3 #6=0 #9=0 #10=0x03ff #11=-1
6 create npc &10               #1=81 #2=3 #6=0 #7=0x04ff #8=-1 #9=0
6 create npc &10 at &7         #1=81 #2=3 #6=0 #9=0
6 #7=12 cure &7                #1=49 #2=2 #6=0
6 cure lycanthropy             #1=59 #2=1
6 cure vampirism               #1=58 #2=1
6 daily from &8 to &11         #1=31 #2=3 #6=0 #7=0x12345678 #9=0 #10=0x12345678
6 destroy &7                   #1=44 #2=2 #6=0
6 drop &7 as questor           #1=86 #2=2 #6=0
6 drop &7 face                 #1=56 #2=2 #6=0
6 drop &7 face saying &18      #1=56 #2=2 #6=0
6 drop foe &7 face             #1=64 #2=2 #6=0
6 dropped &7 at &10            #1=5  #2=3 #6=0 #9=0
6 dropped &7 at &10 saying &18 #1=5  #2=3 #6=0 #9=0
6 end quest                    #1=6  #2=1
6 end quest saying &18         #1=6  #2=1
6 get item &7                       #1=26 #2=3 #6=0 #9=0 #10=0x03ff #11=-1
6 get item &7 saying &18            #1=26 #2=3 #6=0 #9=0 #10=0x03ff #11=-1
6 get item &7 from &10              #1=26 #2=3 #6=0 #9=0
6 give item &7 to &10               #1=39 #2=3 #6=0 #9=0
6 give item &7 to &10 saying &18    #1=39 #2=3 #6=0 #9=0
6 #7=0 give pc &7 notify &18        #1=76 #2=2 #6=0
6 #7=0 give pc &7 silently          #1=76 #2=2 #6=0 #18=-1
6 #7=0 give pc &7 saying &18        #1=4  #2=5 #6=0 #9=0 #10=0xff #11=-1 #12=0 #13=0xff #14=-1 #15=0 #16=0xff #17=-1
6 #7=0 give pc &7                   #1=4  #2=5 #6=0 #9=0 #10=0xff #11=-1 #12=0 #13=0xff #14=-1 #15=0 #16=0xff #17=-1
6 #7=0 give pc &7 and &10           #1=4  #2=5 #6=0 #9=0 #12=0 #13=0xff #14=-1 #15=0 #16=0xff #17=-1
6 #7=0 give pc &7 and &10 and &13   #1=4  #2=5 #6=0 #9=0 #12=0 #15=0 #16=0xff #17=-1
6 #7=0 give pc &7 and &10 and &13 and &16 #1=4 #2=5 #6=0 #9=0  #12=0 #15=0
6 give pc nothing                   #1=4  #2=5 #6=0 #7=255 #8=-1 #9=0 #10=0xff #11=-1 #12=0 #13=0xff #14=-1 #15=0 #16=0xff #17=-1
6 have &10 do &7               #1=70 #2=5 #6=0 #9=0 #12=0 #13=0xff #14=-1 #15=0 #16=0xff #17=-1
6 have &10 set &7              #1=70 #2=5 #6=0 #9=0 #12=0 #13=0xff #14=-1 #15=0 #16=0xff #17=-1
6 have &10 and &13 do &7       #1=70 #2=5 #6=0 #9=0 #12=0 #15=0 #16=0xff #17=-1
6 hide npc &7                  #1=46 #2=2 #6=0
6 hide npc &7 saying &18       #1=46 #2=2 #6=0
6 injured &7 saying &18        #1=21 #2=2
6 injured &7                   #1=21 #2=2
6 killed &11 &7 saying &18     #1=2  #2=3 #6=0 #9=0 #10=0x12345678
6 killed &11 &7                #1=2  #2=3 #6=0 #9=0 #10=0x12345678
6 killed &7                    #1=2  #2=3 #6=0 #9=0 #10=0x12345678 #11=1
6 legal repute &8              #1=65 #2=2 #6=0 #7=0x12345678
6 level &8 completed           #1=77 #2=2 #6=0 #7=0x12345678
--	&11 and &14 appear to be times.
6 location &7 &11 &14          #1=17 #2=4 #6=0 #9=0 #10=0x12345678 #12=0 #13=0x12345678
6 log &8 &11                   #1=23 #2=3 #6=0 #7=10 #9=0 #10=0x12345678
6 log &8 step &11              #1=23 #2=3 #6=0 #7=10 #9=0 #10=0x12345678
6 make &7 permanent            #1=54 #2=2 #6=0
6 make &7 permanent saying &18 #1=54 #2=2 #6=0
6 #7=12 make pc ill with &7              #1=72 #2=2 #6=0
6 #7=12 make pc ill with &7 saying &18   #1=72 #2=2 #6=0
6 mute npc &7                  #1=82 #2=2
6 pc at &10 do &7              #1=43 #2=3 #6=0 #9=0
6 pc at &10 do &7 saying &18   #1=43 #2=3 #6=0 #9=0
6 pc at &10 set &7             #1=43 #2=3 #6=0 #9=0
6 pc at &10 set &7 saying &18  #1=43 #2=3 #6=0 #9=0
6 pick one of &7               #1=34 #2=5 #6=0 #9=0 #10=0x09fe #11=-2 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 pick one of &7 &10           #1=34 #2=5 #6=0 #9=0 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 pick one of &7 &10 &13       #1=34 #2=5 #6=0 #9=0 #12=0 #15=0 #16=0x09fe #17=-2
6 pick one of &7 &10 &13 &16   #1=34 #2=5 #6=0 #9=0 #12=0 #15=0
8 place &7 at &10                    #1=0x16001e00 #2=3 #6=0 #9=0
6 place foe &7 at &10                #1=22 #2=3 #6=0 #9=0
6 place foe &7 at &10 saying &18     #1=22 #2=3 #6=0 #9=0
6 place item &7 at &10               #1=0  #2=3 #6=0 #9=0
6 place item &7 at &10 saying &18    #1=0  #2=3 #6=0 #9=0
6 place npc &7 at &10                #1=30 #2=3 #6=0 #9=0
6 #7=13 play sound &7          #1=84 #2=4 #6=0 #9=0 #10=0x12345678 #11=5 #12=0 #13=0x12345678 #14=25
6 #7=13 play sound &7 every &11 minutes &14 times   #1=84 #2=4 #6=0 #9=0 #10=0x12345678 #12=0 #13=0x12345678
-6      play sound &8 &11 &14  #1=84 #2=4 #6=0 #7=0x12345678 #9=0 #10=0x12345678 #12=0 #13=0x12345678
6 play video &8                #1=50 #2=2 #6=0 #7=0x12345678
6 prompt &14 yes &7 no &10     #1=29 #2=4 #6=0 #9=0 #12=0 #13=10
6 reset dialog                 #1=10 #2=4 #6=0 #7=0x04ff #8=-1 #9=0 #10=0x03ff #11=-1 #12=0 #13=0xff #14=-1
6 repute with &10 exceeds &14 do &7   #1=37 #2=4 #6=0 #9=0#12=0 #13=0x12345678
6 restore &7                          #1=48 #2=2 #6=0
6 restrain foe &7                     #1=68 #2=3 #6=0 #9=0 #10=0x09ff #11=-1
6 restrain foe &7 task &10            #1=68 #2=3 #6=0 #9=0
6 reveal &7                           #1=19 #2=2 #6=0
6 reveal &7 saying &18                #1=19 #2=2 #6=0
6 reveal &7 in province &11 at &14    #1=27 #2=4 #6=0 #9=0 #10=0x12345678 #12=0 #13=0x12345678
6 rumor mill &8                       #1=38 #2=2 #6=0 #7=10
6 #18=10 say &18                      #1=51 #2=1
6        say nothing                  #1=51 #2=1 #18=-1
6      send foe &7 every &11 minutes &17 times with &14 success  #1=87 #2=5 #6=0 #9=0 #10=0x1234567 #12=0 #13=0x1234567 #15=0 #16=0x1234567
6 #7=7 send &7 every &11 minutes with &14 success                #1=87 #2=5 #6=0 #9=0 #10=0x1234567 #12=0 #13=0x1234567 #15=0 #16=0x1234567 #17=-1
6 #7=7 send &7 every &11 minutes &17 times with &14 success      #1=87 #2=5 #6=0 #9=0 #10=0x1234567 #12=0 #13=0x1234567 #15=0 #16=0x1234567
6 start quest &8 &11                  #1=8  #2=3 #6=0 #7=0x12345678 #9=0 #10=0x12345678
6 start task &7                       #1=35 #2=5 #6=0 #9=0 #10=0x09fe #11=-2 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 start timer &7                      #1=12 #2=2 #6=0
6 stop timer &7                       #1=13 #2=2 #6=0
6 take &7 from pc saying &18          #1=36 #2=2 #6=0
6 take &7 from pc                     #1=36 #2=2 #6=0 #18=-1
6 teleport pc to &10                  #1=30 #2=3 #6=0 #7=0x03ff #8=-1 #9=0
6 toting &7 and &10 clicked           #1=1  #2=3 #6=0 #9=0
6 toting &7 and &10 clicked saying &18      #1=1 #2=3 #6=0 #9=0
6 transfer pc inside &7 &11 &14       #1=83 #2=4 #6=0 #9=0 #10=0x12345678 #12=0 #13=0x12345678
10 unset &7 &10 &13 &16               #1=7  #2=5 #6=0 #9=0 #12=0 #15=0
10 unset &7 &10 &13                   #1=7  #2=5 #6=0 #9=0 #12=0 #15=0 #16=0x09fe #17=-2
10 unset &7 &10                       #1=7  #2=5 #6=0 #9=0 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
10 unset &7                           #1=7  #2=5 #6=0 #9=0 #10=0x09fe #11=-2 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 #10=0 &10 used do &7                #1=57 #2=3 #6=0 #9=0
6 #10=0 &10 used saying &18 do &7     #1=57 #2=3 #6=0 #9=0
6 when &7                             #1=52 #2=5 #6=0 #9=0 #10=0x09fe #11=-2 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 when not &7                         #1=52 #2=5 #6=1 #9=0 #10=0x09fe #11=-2 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 when     &7 and     &10 saying &18  #1=52 #2=5 #6=0 #9=0 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 when     &7 and     &10             #1=52 #2=5 #6=0 #9=0 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 when not &7 and     &10             #1=52 #2=5 #6=1 #9=0 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 when not &7 and not &10             #1=52 #2=5 #6=1 #9=1 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 when     &7 and not &10             #1=52 #2=5 #6=0 #9=1 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 when     &7 and     &10 and     &13 #1=52 #2=5 #6=0 #9=0 #12=0 #15=0 #16=0x09fe #17=-2
6 when     &7 and     &10 and     &13 saying &18 #1=52 #2=5 #6=0 #9=0 #12=1 #15=0 #16=0x09fe #17=-2
6 when     &7 and not &10 and not &13 #1=52 #2=5 #6=0 #9=1 #12=1 #15=0 #16=0x09fe #17=-2
6 when     &7 and     &10 and not &13 #1=52 #2=5 #6=0 #9=0 #12=1 #15=0 #16=0x09fe #17=-2
6 when     &7 and     &10 and not &13 saying &18 #1=52 #2=5 #6=0 #9=0 #12=1 #15=0 #16=0x09fe #17=-2
6 when     &7 and not &10 and     &13 #1=52 #2=5 #6=0 #9=1 #12=0 #15=0 #16=0x09fe #17=-2
6 when not &7 and     &10 and     &13 #1=52 #2=5 #6=1 #9=0 #12=0 #15=0 #16=0x09fe #17=-2
6 when not &7 and not &10 and     &13 #1=52 #2=5 #6=1 #9=1 #12=0 #15=0 #16=0x09fe #17=-2
6 when not &7 and     &10 and not &13 #1=52 #2=5 #6=1 #9=0 #12=1 #15=0 #16=0x09fe #17=-2
6 when not &7 and not &10 and not &13 #1=52 #2=5 #6=1 #9=1 #12=1 #15=0 #16=0x09fe #17=-2
6 when     &7 and     &10 and     &13 and     &16    #1=52 #2=5 #6=0 #9=0 #12=0 #15=0
6 when     &7 and     &10 and     &13 and not &16    #1=52 #2=5 #6=0 #9=0 #12=0 #15=1
6 when     &7 and     &10 and not &13 and     &16    #1=52 #2=5 #6=0 #9=0 #12=1 #15=0
6 when     &7 and     &10 and not &13 and not &16    #1=52 #2=5 #6=0 #9=0 #12=1 #15=1
6 when     &7 and not &10 and     &13 and     &16    #1=52 #2=5 #6=0 #9=1 #12=0 #15=0
6 when     &7 and not &10 and     &13 and not &16    #1=52 #2=5 #6=0 #9=1 #12=0 #15=1
6 when     &7 and not &10 and not &13 and     &16    #1=52 #2=5 #6=0 #9=1 #12=1 #15=0
6 when     &7 and not &10 and not &13 and not &16    #1=52 #2=5 #6=0 #9=1 #12=1 #15=1
6 when not &7 and     &10 and     &13 and     &16    #1=52 #2=5 #6=1 #9=0 #12=0 #15=0
6 when not &7 and     &10 and     &13 and not &16    #1=52 #2=5 #6=1 #9=0 #12=0 #15=1
6 when not &7 and     &10 and not &13 and     &16    #1=52 #2=5 #6=1 #9=0 #12=1 #15=0
6 when not &7 and     &10 and not &13 and not &16    #1=52 #2=5 #6=1 #9=0 #12=1 #15=1
6 when not &7 and not &10 and     &13 and     &16    #1=52 #2=5 #6=1 #9=1 #12=0 #15=0
6 when not &7 and not &10 and     &13 and not &16    #1=52 #2=5 #6=1 #9=1 #12=0 #15=1
6 when not &7 and not &10 and not &13 and     &16    #1=52 #2=5 #6=1 #9=1 #12=1 #15=0
6 when not &7 and not &10 and not &13 and not &16    #1=52 #2=5 #6=1 #9=1 #12=1 #15=1
6 when     &7 or     &10              #1=53 #2=5 #6=0 #9=0 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 when not &7 or     &10              #1=53 #2=5 #6=1 #9=0 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 when     &7 or not &10              #1=53 #2=5 #6=0 #9=1 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 when not &7 or not &10              #1=53 #2=5 #6=1 #9=1 #12=0 #13=0x09fe #14=-2 #15=0 #16=0x09fe #17=-2
6 when     &7 or     &10 or     &13   #1=53 #2=5 #6=0 #9=0 #12=0 #15=0 #16=0x09fe #17=-2
6 when     &7 or not &10 or not &13   #1=53 #2=5 #6=0 #9=1 #12=1 #15=0 #16=0x09fe #17=-2
6 when     &7 or     &10 or not &13   #1=53 #2=5 #6=0 #9=0 #12=1 #15=0 #16=0x09fe #17=-2
6 when     &7 or not &10 or     &13   #1=53 #2=5 #6=0 #9=1 #12=0 #15=0 #16=0x09fe #17=-2
6 when not &7 or     &10 or not &13   #1=53 #2=5 #6=1 #9=0 #12=1 #15=0 #16=0x09fe #17=-2
6 when     &7 or     &10 or     &13 or     &16 #1=53 #2=5 #6=0 #9=0 #12=0 #15=0
6 when not &7 or not &10 or not &13 or not &16 #1=53 #2=5 #6=1 #9=1 #12=1 #15=1
6 #7=14 when &7 is available                   #1=78 #2=2 #6=0
6 #7=14 when repute with &7 is at least &11    #1=79 #2=3 #6=0 #9=0 #10=0x12345678
